==> plus-watermark-1.0.14.jar: scripts/util/watermark-common-pwe.js <==
window.Watermark = {
	t: PW.I18N.createT("com.suncode.plugin-plus-watermark"),

	addComboboxClassList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/docs/docClasses",
				fields: [
					{
						name: "name",
						type: "string"
					}
				]
			},
			valueField: "name",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxAlignmentList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/alignments",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxAnchorList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/anchors",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxBarcodeFormatList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/barcodeFormats",
				fields: [
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "value",
			sort: [{
				property: "value",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxRotationMechanismList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/rotationMechanism",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxFontTypeList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/fontTypes",
				fields: [
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "value",
			sort: [{
				property: "value",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxColorList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/colors",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxEncodingList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/encodings",
				fields: [
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "value",
			sort: [{
				property: "value",
				direction: "ASC"
			}]
		}, position);
	}
}

==> plus-watermark-1.0.15.jar: scripts/util/watermark-common-pwe.js <==
window.Watermark = {
	t: PW.I18N.createT("com.suncode.plugin-plus-watermark"),

	addComboboxClassList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/docs/docClasses",
				fields: [
					{
						name: "name",
						type: "string"
					}
				]
			},
			valueField: "name",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxAlignmentList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/alignments",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxAnchorList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/anchors",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxBarcodeFormatList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/barcodeFormats",
				fields: [
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "value",
			sort: [{
				property: "value",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxRotationMechanismList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/rotationMechanism",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxFontTypeList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/fontTypes",
				fields: [
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "value",
			sort: [{
				property: "value",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxColorList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/colors",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxEncodingList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/encodings",
				fields: [
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "value",
			sort: [{
				property: "value",
				direction: "ASC"
			}]
		}, position);
	},

	addComboboxPageSelectionList: function (idName, form, position) {
		form.addCombobox({
			id: idName,
			remote: {
				url: "plugin/com.suncode.plugin-plus-watermark/config/pageSelections",
				fields: [
					{
						name: "name",
						type: "string"
					},
					{
						name: "value",
						type: "string"
					}
				]
			},
			valueField: "value",
			displayField: "name",
			sort: [{
				property: "name",
				direction: "ASC"
			}]
		}, position);
	}
}
